pub struct DenseFoldPlan {
pub n_inputs: usize,
pub n_outputs: usize,
pub mac_count: u32,
pub dsp_budget: u32,
pub output_parallelism: u32,
pub input_parallelism: u32,
pub dsp_per_cycle: u32,
pub input_fold_factor: u32,
pub output_fold_factor: u32,
pub compute_cycles: u32,
pub fold_required: bool,
pub fits_dsp_budget: bool,
}Expand description
Deterministic time-multiplexing plan for dense layers that exceed a target one-DSP-per-MAC budget.
Fields
n_inputs: usizen_outputs: usizemac_count: u32dsp_budget: u32output_parallelism: u32input_parallelism: u32dsp_per_cycle: u32input_fold_factor: u32output_fold_factor: u32compute_cycles: u32fold_required: boolfits_dsp_budget: boolTrait Implementations
Sourceimpl Clone for DenseFoldPlan
impl Clone for DenseFoldPlan
Sourcefn clone(&self) -> DenseFoldPlan
fn clone(&self) -> DenseFoldPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DenseFoldPlan
impl Debug for DenseFoldPlan
impl Eq for DenseFoldPlan
Sourceimpl PartialEq for DenseFoldPlan
impl PartialEq for DenseFoldPlan
Sourcefn eq(&self, other: &DenseFoldPlan) -> bool
fn eq(&self, other: &DenseFoldPlan) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DenseFoldPlan